@@ -124,9 +124,8 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     app.setOrganizationName(QStringLiteral("Maui"));
     app.setWindowIcon(QIcon(":/assets/pix.png"));
 
-    MauiApp::instance()->setIconName("qrc:/assets/pix.svg");
-
     KLocalizedString::setApplicationDomain("pix");
+
     KAboutData about(QStringLiteral("pix"), i18n("Pix"), PIX_VERSION_STRING, i18n("Organize, browse, and edit your images."), KAboutLicense::LGPL_V3, i18n("© 2019-%1 Maui Development Team", QString::number(QDate::currentDate().year())), QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
     about.addAuthor(i18n("Camilo Higuita"), i18n("Developer"), QStringLiteral("milo.h@aol.com"));
     about.setHomepage("https://mauikit.org");
@@ -134,8 +133,10 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     about.setBugAddress("https://invent.kde.org/maui/pix/-/issues");
     about.setOrganizationDomain(PIX_URI);
     about.setProgramLogo(app.windowIcon());
+    about.addComponent("Exiv2");
 
     KAboutData::setApplicationData(about);
+    MauiApp::instance()->setIconName("qrc:/assets/pix.png");
 
     QCommandLineParser parser;
 
@@ -179,6 +180,8 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     },
     Qt::QueuedConnection);
 
+    engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
+
     engine.rootContext()->setContextProperty("initModule", arguments.first);
     engine.rootContext()->setContextProperty("initData", QUrl::toStringList(arguments.second));
 
