@@ -37,53 +37,17 @@ static FMH::MODEL picInfo2(const QUrl &url)
 
 Gallery::Gallery(QObject *parent)
     : MauiList(parent)
-    , m_fileLoader(new FMH::FileLoader())
+    , m_fileLoader(new FMH::FileLoader(this))
     , m_watcher(new QFileSystemWatcher(this))
     , m_autoReload(true)
     , m_recursive(true)
 {
     qDebug() << "CREATING GALLERY LIST";
-    m_fileLoader->informer = m_activeGeolocationTags ? &picInfo2 : &picInfo;
-    m_fileLoader->setBatchCount(500);
-    connect(m_fileLoader, &FMH::FileLoader::finished, [this](FMH::MODEL_LIST items) {
-        Q_UNUSED(items)
-
-        emit this->filesChanged();
-        emit this->citiesChanged();
-        emit this->foldersChanged();
-
-        this->setStatus(Status::Ready);
-    });
-
-    connect(m_fileLoader, &FMH::FileLoader::itemsReady, [this](FMH::MODEL_LIST items) {
-        qDebug() << "Items ready" << items.size();
-
-        if (items.isEmpty())
-            return;
-
-        emit preItemsAppended(items.size());
-        this->list << items;
-        emit postItemAppended();
-        emit this->countChanged();
-    });
-
-    connect(m_fileLoader, &FMH::FileLoader::itemReady, [this](FMH::MODEL item) {
-        this->insertFolder(item[FMH::MODEL_KEY::SOURCE]);
-        if(m_activeGeolocationTags)
-        {
-            this->insertCity(item[FMH::MODEL_KEY::CITY]);
-        }
-    });
-
-    connect(m_watcher, &QFileSystemWatcher::directoryChanged, [this](QString dir) {
-        qDebug() << "Dir changed" << dir;
-        this->rescan();
-    });
 }
 
 Gallery::~Gallery()
 {
-    delete m_fileLoader;
+//    delete m_fileLoader;
 }
 
 const FMH::MODEL_LIST &Gallery::items() const
@@ -266,11 +230,15 @@ void Gallery::clear()
 void Gallery::rescan()
 {
     this->clear();
-    this->reload();
+    this->load();
 }
 
-void Gallery::reload()
-{
+void Gallery::load()
+{    
+    qDebug() << "ASK TO LOAD GALLERY" << m_activeGeolocationTags;
+    m_fileLoader->informer = m_activeGeolocationTags ? &picInfo2 : &picInfo;
+    m_fileLoader->setBatchCount(500);
+
     this->scan(m_urls, m_recursive, m_limit);
 }
 
@@ -315,8 +283,51 @@ void Gallery::setActiveGeolocationTags(bool activeGeolocationTags)
 
 void Gallery::componentComplete()
 {
+    connect(m_fileLoader, &FMH::FileLoader::finished, [this](FMH::MODEL_LIST items) {
+        Q_UNUSED(items)
+
+        emit this->filesChanged();
+        emit this->citiesChanged();
+        emit this->foldersChanged();
+
+        this->setStatus(Status::Ready);
+    });
+
+    connect(m_fileLoader, &FMH::FileLoader::itemsReady, [this](FMH::MODEL_LIST items) {
+        qDebug() << "Items ready" << items.size();
+
+        if (items.isEmpty())
+            return;
+
+        emit preItemsAppended(items.size());
+        this->list << items;
+        emit postItemAppended();
+        emit this->countChanged();
+    });
+
+    connect(m_fileLoader, &FMH::FileLoader::itemReady, [this](FMH::MODEL item) {
+        this->insertFolder(item[FMH::MODEL_KEY::SOURCE]);
+        if(m_activeGeolocationTags)
+        {
+            this->insertCity(item[FMH::MODEL_KEY::CITY]);
+        }
+    });
+
+    connect(m_watcher, &QFileSystemWatcher::directoryChanged, [this](QString dir) {
+        qDebug() << "Dir changed" << dir;
+        this->rescan();
+    });
+
     connect(this, &Gallery::urlsChanged, this, &Gallery::rescan);
-    this->reload();
+    connect(this, &Gallery::activeGeolocationTagsChanged, [this](bool state)
+    {
+       if(state)
+       {
+           this->rescan();
+       }
+    });
+
+    this->load();
 }
 
 const QStringList &Gallery::cities() const
